@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_x_monotone_2.h $
-// $Id: Bezier_x_monotone_2.h 3dc2804 2020-08-11T13:23:08+02:00 Ahmed Essam
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_x_monotone_2.h $
+// $Id: include/CGAL/Arr_geometry_traits/Bezier_x_monotone_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Ron Wein     <wein@post.tau.ac.il>
@@ -130,7 +130,7 @@ private:
     Rational t_min;
     Rational t_max;
 
-    /*! Get the rational bounding box of the subcurve. */
+    /*! obtains the rational bounding box of the subcurve. */
     void bbox(Rational& x_min, Rational& y_min,
               Rational& x_max, Rational& y_max) const
     {
@@ -318,13 +318,11 @@ public:
                            Bezier_cache& cache,
                            OutputIterator oi) const
   {
-    typedef boost::variant<Intersection_point, Self>    Intersection_result;
-
     // In case we have two x-monotone subcurves of the same Bezier curve,
     // check if they have a common left endpoint.
     if (_curve.is_same(cv._curve)) {
       if (left().is_same(cv.left()) || left().is_same(cv.right()))
-        *oi++ = Intersection_result(Intersection_point(left(), 0));
+        *oi++ = Intersection_point(left(), 0);
     }
 
     // Compute the intersections of the two sucurves. Note that for caching
@@ -341,7 +339,7 @@ public:
 
     // In case of overlap, just report the overlapping subcurve.
     if (do_ovlp) {
-      *oi++ = Intersection_result(ovlp_cv);
+      *oi++ = ovlp_cv;
       return oi;
     }
 
@@ -349,14 +347,14 @@ public:
     // xy-lexicorgraphical order, and insert them to the output iterator.
     std::sort(ipts.begin(), ipts.end(), Less_intersection_point(cache));
     for (auto ip_it = ipts.begin(); ip_it != ipts.end(); ++ip_it) {
-      *oi++ = Intersection_result(*ip_it);
+      *oi++ = *ip_it;
     }
 
     // In case we have two x-monotone subcurves of the same Bezier curve,
     // check if they have a common right endpoint.
     if (_curve.is_same(cv._curve)) {
       if (right().is_same(cv.left()) || right().is_same(cv.right())) {
-        *oi++ = Intersection_result(Intersection_point(right(), 0));
+        *oi++ = Intersection_point(right(), 0);
       }
     }
 
@@ -466,7 +464,7 @@ private:
                                     const Point_2& p,
                                     Bezier_cache& cache) const;
 
-  /*! Get the range of t-value over which the subcurve is defined.
+  /*! obtains the range of t-value over which the subcurve is defined.
    * \param cache Caches the vertical tangency points and intersection points.
    * \return A pair comprised of the t-value for the source point and the
    *         t-value for the target point.
@@ -533,7 +531,7 @@ private:
   /*! Compute the exact vertical position of the given point with respect to
    * the x-monotone curve.
    * \param p The point.
-   * \param force_exact Sould we force an exact result.
+   * \param force_exact Should we force an exact result.
    * \return SMALLER if the point is below the curve;
    *         LARGER if the point is above the curve;
    *         EQUAL if p lies on the curve.
@@ -751,7 +749,7 @@ point_position(const Point_2& p, Bezier_cache& cache) const
     in_range = _is_in_range(p, correct_res);
 
     if (! correct_res) {
-      // Perform the comparsion in an exact manner.
+      // Perform the comparison in an exact manner.
       if (! p.is_exact())
         p.make_exact(cache);
 
@@ -764,7 +762,7 @@ point_position(const Point_2& p, Bezier_cache& cache) const
   }
 
   // Call the vertical-position function that uses the bounding-boxes
-  // to evaluate the comparsion result.
+  // to evaluate the comparison result.
   typename Bounding_traits::Control_points cp;
 
   std::copy(_curve.control_points_begin(), _curve.control_points_end(),
@@ -1192,7 +1190,7 @@ _Bezier_x_monotone_2<RatKer, AlgKer, NtTrt, BndTrt>::compare_to_left
     return (slope_res);
 
   // Compare the two subcurves by choosing some point to the left of p
-  // and compareing the vertical position there.
+  // and comparing the vertical position there.
   Comparison_result   left_res;
 
   if (left().compare_x(cv.left(), cache) != SMALLER)
@@ -1376,7 +1374,7 @@ _is_in_range(const Algebraic& t, Bezier_cache& cache) const
     return (false);
   }
 
-  // Obtain the exact t-range of the curve and peform an exact comparison.
+  // Obtain the exact t-range of the curve and perform an exact comparison.
   std::pair<Algebraic, Algebraic> range = _t_range (cache);
   const Algebraic&                t_src = range.first;
   const Algebraic&                t_trg = range.second;
@@ -1923,7 +1921,7 @@ _clip_control_polygon(typename Bounding_traits::Control_points& ctrl,
   if (! (org_min->point_bound().type == Bez_point_bound::RATIONAL_PT &&
          CGAL::sign(org_min->point_bound().t_min) == CGAL::ZERO))
   {
-    // It is possible that the paramater range of the originator is too large.
+    // It is possible that the parameter range of the originator is too large.
     // We therefore make sure it fits the current bounding box of the point
     // (which we know is tight enough).
     p_min.fit_to_bbox();
@@ -1951,7 +1949,7 @@ _clip_control_polygon(typename Bounding_traits::Control_points& ctrl,
   if (! (org_max->point_bound().type == Bez_point_bound::RATIONAL_PT &&
          CGAL::compare (org_max->point_bound().t_max, 1) == CGAL::EQUAL))
   {
-    // It is possible that the paramater range of the originator is too large.
+    // It is possible that the parameter range of the originator is too large.
     // We therefore make sure it fits the current bounding box of the point
     // (which we know is tight enough).
     p_max.fit_to_bbox();
@@ -2140,7 +2138,7 @@ _intersect(const Self& cv,
   else {
     // Approximate the intersection points and store them in the map.
     // Note that we do not store approximated self-intersections in the map,
-    // as they realte only to the pecific x-monotone curves, and not to the
+    // as they relate only to the specific x-monotone curves, and not to the
     // entire curve.
     app_ok = _approximate_intersection_points(cv, inter_pts);
 
@@ -2435,7 +2433,7 @@ _exact_vertical_position(const Point_2& p,
 #endif
                          ) const
 {
-  // If it is a rational point, obtain its rational reprsentation.
+  // If it is a rational point, obtain its rational representation.
   Rat_point_2              rat_p;
 
   if (p.is_rational())
@@ -2587,6 +2585,7 @@ _exact_vertical_position(const Point_2& p,
   return EQUAL;
 }
 
-} //namespace CGAL
+} // namespace CGAL
 
 #endif
+
