@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Basic_viewer/include/CGAL/Buffer_for_vao.h $
-// $Id: include/CGAL/Buffer_for_vao.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Basic_viewer/include/CGAL/Buffer_for_vao.h $
+// $Id: include/CGAL/Buffer_for_vao.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,6 +16,7 @@
 
 #include <CGAL/license/GraphicsView.h>
 
+#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
 #include <CGAL/Projection_traits_3.h>
 #include <CGAL/Triangulation_vertex_base_with_info_2.h>
 #include <CGAL/Triangulation_face_base_with_info_2.h>
@@ -146,7 +147,7 @@ namespace internal
         {
           typename CDT::Edge e(fh,i);
           auto n = fh->neighbor(i);
-          if (n->info().m_nesting_level==-1)
+          if (n!=nullptr && n->info().m_nesting_level==-1)
           {
             if (tri.is_constrained(e)) { border.push(e); }
             else { queue.push(n); }
@@ -884,13 +885,13 @@ protected:
   typedef CGAL::Constrained_Delaunay_triangulation_2<P_traits, TDS, Itag>    CDT;
 
 protected:
-  std::vector<BufferType>* m_pos_buffer;
-  std::vector<IndexType>* m_index_buffer;
-  std::vector<BufferType>* m_color_buffer;
-  mutable std::vector<BufferType>* m_flat_normal_buffer;
-  mutable std::vector<BufferType>* m_gouraud_normal_buffer;
+  std::vector<BufferType>* m_pos_buffer=nullptr;
+  std::vector<IndexType>* m_index_buffer=nullptr;
+  std::vector<BufferType>* m_color_buffer=nullptr;
+  mutable std::vector<BufferType>* m_flat_normal_buffer=nullptr;
+  mutable std::vector<BufferType>* m_gouraud_normal_buffer=nullptr;
 
-  CGAL::Bbox_3* m_bb;
+  CGAL::Bbox_3* m_bb=nullptr;
 
   bool m_zero_x; /// True iff all points have x==0
   bool m_zero_y; /// True iff all points have y==0
