@@ -1,4 +1,3 @@
-#include <Rcpp.h>
 /****************************************************************************
  * Core Library Version 1.7, August 2004
  * Copyright (c) 1995-2004 Exact Computation Project
@@ -19,8 +18,8 @@
  * WWW URL: https://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL: https://github.com/CGAL/cgal/blob/v5.6.1/CGAL_Core/include/CGAL/CORE/CoreAux_impl.h $
- * $Id: CoreAux_impl.h b5c21e1 2022-11-23T18:48:43+01:00 Mael Rouxel-Labbé
+ * $URL: https://github.com/CGAL/cgal/blob/v6.1/CGAL_Core/include/CGAL/CORE/CoreAux_impl.h $
+ * $Id: include/CGAL/CORE/CoreAux_impl.h b26b07a1242 $
  * SPDX-License-Identifier: LGPL-3.0-or-later
  ***************************************************************************/
 
@@ -32,7 +31,6 @@
 
 #include <CGAL/use.h>
 #include <CGAL/CORE/CoreAux.h>
-#include <CGAL/gmp.h>
 
 namespace CORE {
 
@@ -158,31 +156,6 @@ int IntExponent(double d) {
         return e-53;
 }
 
-/// core_error is the method to write Core Library warning or error messages
-/**         Both warnings and errors are written to a file called CORE_DIAGFILE.
- *        But errors are also written on Rcpp::Rcerr (similar to std::perror()).
- * */
-// Usage: core_error(message, file_with_error, line_number, err_type)
-//   where err_type=0 means WARNING, error_type=0 means ERROR
-CGAL_INLINE_FUNCTION
-void core_error(std::string msg, std::string file, int lineno, bool err) {
-  std::ofstream outFile(CORE_DIAGFILE, std::ios::app);  // open to append
-  if (!outFile) {
-     // perror("CORE ERROR: cannot open Core Diagnostics file");
-     Rcpp::Rcerr << "CORE ERROR: can't open Core Diagnostics file"<<std::endl;
-     Rcpp::stop("Error"); //Note: do not callRcpp::stop("Error")
-  }
-  outFile << "CORE " << (err? "ERROR" : "WARNING")
-     << " (at " << file << ": " << lineno << "): "
-     << msg << std::endl;
-  outFile.close();
-  if (err) {
-     Rcpp::Rcerr << (std::string("CORE ERROR") + " (file " + file + ", line "
-                   + std::to_string(lineno) +"):" + msg + "\n").c_str();
-     Rcpp::stop("Error"); //Note: do not callRcpp::stop("Error")
-  }
-}
-
 
 } //namespace CORE
 
