@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Surface_mesher/include/CGAL/Complex_2_in_triangulation_3.h $
-// $Id: Complex_2_in_triangulation_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Surface_mesher/include/CGAL/Complex_2_in_triangulation_3.h $
+// $Id: include/CGAL/Complex_2_in_triangulation_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,6 +16,11 @@
 
 #include <CGAL/license/Surface_mesher.h>
 
+#define CGAL_DEPRECATED_HEADER "<CGAL/Complex_2_in_triangulation_3.h>"
+#define CGAL_DEPRECATED_MESSAGE_DETAILS \
+  "The 3D Mesh Generation package (see https://doc.cgal.org/latest/Mesh_3/) should be used instead."
+#include <CGAL/Installation/internal/deprecation_warning.h>
+
 #include <CGAL/disable_warnings.h>
 
 // TODO: add the iterators
@@ -768,7 +773,7 @@ operator>> (std::istream& is, Complex_2_in_triangulation_3<Tr, Edge_info>& c2t3)
   c2t3.clear();
   is >> c2t3.triangulation();
 
-  // restore datas of c2t3
+  // restore data of c2t3
   for(typename Tr::Finite_facets_iterator fit =
         c2t3.triangulation().finite_facets_begin();
       fit != c2t3.triangulation().finite_facets_end();
@@ -791,3 +796,4 @@ operator<< (std::ostream& os, const Complex_2_in_triangulation_3<Tr, Edge_info>
 #include <CGAL/enable_warnings.h>
 
 #endif // CGAL_COMPLEX_2_IN_TRIANGULATION_3_H
+
