@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Filtered_kernel/include/CGAL/Filtered_construction.h $
-// $Id: Filtered_construction.h c8624ee 2021-09-09T11:01:03+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Filtered_kernel/include/CGAL/Filtered_construction.h $
+// $Id: include/CGAL/Filtered_construction.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,6 +16,8 @@
 #include <CGAL/basic.h>
 #include <CGAL/Interval_arithmetic.h>
 
+#include <type_traits>
+
 namespace CGAL {
 
 template <class AC, class EC, class FC, class C2E, class C2F,
@@ -30,82 +32,71 @@ private:
   E2C From_Exact;
   F2C From_Filtered;
 
-  typedef typename AC::result_type  AC_result_type;
-  typedef typename FC::result_type  FC_result_type;
-  typedef typename EC::result_type  EC_result_type;
-
-public:
-  typedef AC_result_type           result_type;
-
 public:
   Filtered_construction() {}
 
   template <class A1>
-  result_type
-  operator()(const A1 &a1) const
+  auto operator()(const A1 &a1) const
+    -> typename std::invoke_result<AC, A1>::type
   {
     {
-      // Protection is outside the try block as VC8 has the CGAL_CFG_FPU_ROUNDING_MODE_UNWINDING_VC_BUG
       Protect_FPU_rounding<Protection> P1;
       try
       {
-        return From_Filtered( Filter_construction(To_Filtered(a1)) );
+        return From_Filtered(Filter_construction(To_Filtered(a1)));
       }
       catch (Uncertain_conversion_exception&)
       {}
     }
     Protect_FPU_rounding<!Protection> P(CGAL_FE_TONEAREST);
     CGAL_expensive_assertion(FPU_get_cw() == CGAL_FE_TONEAREST);
-    return From_Exact( Exact_construction(To_Exact(a1)) );
+    return From_Exact(Exact_construction(To_Exact(a1)));
   }
+
   template <class A1, class A2>
-  result_type
-  operator()(const A1 &a1, const A2 &a2) const
+  auto operator()(const A1 &a1, const A2 &a2) const
+    -> typename std::invoke_result<AC, A1, A2>::type
   {
     {
       Protect_FPU_rounding<Protection> P1;
       try
       {
-        return From_Filtered( Filter_construction(To_Filtered(a1),
-                                                  To_Filtered(a2)) );
+        return From_Filtered(Filter_construction(To_Filtered(a1),
+                                                 To_Filtered(a2)));
       }
       catch (Uncertain_conversion_exception&)
       {}
     }
     Protect_FPU_rounding<!Protection> P(CGAL_FE_TONEAREST);
     CGAL_expensive_assertion(FPU_get_cw() == CGAL_FE_TONEAREST);
-    return From_Exact( Exact_construction(To_Exact(a1),
-                                          To_Exact(a2)) );
+    return From_Exact(Exact_construction(To_Exact(a1),
+                                         To_Exact(a2)));
   }
 
   template <class A1, class A2, class A3>
-  result_type
-  operator()(const A1 &a1, const A2 &a2, const A3 &a3) const
+  auto operator()(const A1 &a1, const A2 &a2, const A3 &a3) const
+    -> typename std::invoke_result<AC, A1, A2, A3>::type
   {
     {
       Protect_FPU_rounding<Protection> P1;
       try
       {
-        return From_Filtered( Filter_construction(To_Filtered(a1),
-                                                  To_Filtered(a2),
-                                                  To_Filtered(a3)) );
+        return From_Filtered(Filter_construction(To_Filtered(a1),
+                                                 To_Filtered(a2),
+                                                 To_Filtered(a3)));
       }
       catch (Uncertain_conversion_exception&)
       {}
     }
     Protect_FPU_rounding<!Protection> P(CGAL_FE_TONEAREST);
     CGAL_expensive_assertion(FPU_get_cw() == CGAL_FE_TONEAREST);
-    return From_Exact( Exact_construction(To_Exact(a1),
-                                          To_Exact(a2),
-                                          To_Exact(a3)) );
+    return From_Exact(Exact_construction(To_Exact(a1),
+                                         To_Exact(a2),
+                                         To_Exact(a3)));
   }
-
 };
 
-
-
-} //namespace CGAL
-
+} // namespace CGAL
 
 #endif // CGAL_FILTERED_CONSTRUCTION_H
 
