@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Orientation_2.h $
-// $Id: Orientation_2.h 5945e48 2021-09-17T08:14:06+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Orientation_2.h $
+// $Id: include/CGAL/Filtered_kernel/internal/Static_filters/Orientation_2.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -26,16 +26,14 @@ template < typename K_base >
 class Orientation_2
   : public K_base::Orientation_2
 {
+  typedef typename K_base::Orientation      Orientation;
   typedef typename K_base::Point_2          Point_2;
   typedef typename K_base::Vector_2         Vector_2;
-  typedef typename K_base::Circle_2          Circle_2;
+  typedef typename K_base::Circle_2         Circle_2;
 
   typedef typename K_base::Orientation_2    Base;
 
 public:
-
-  typedef typename Base::result_type  result_type;
-
   using Base::operator();
 
   Orientation
