@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Homogeneous_kernel/include/CGAL/Homogeneous/distance_predicatesH2.h $
-// $Id: include/CGAL/Homogeneous/distance_predicatesH2.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Homogeneous_kernel/include/CGAL/Homogeneous/distance_predicatesH2.h $
+// $Id: include/CGAL/Homogeneous/distance_predicatesH2.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,7 +24,7 @@ namespace CGAL {
 
 template < class R>
 CGAL_KERNEL_MEDIUM_INLINE
-bool
+typename R::Boolean
 has_larger_distance_to_point(const PointH2<R>& p,
                               const PointH2<R>& q,
                               const PointH2<R>& r)
@@ -74,7 +74,7 @@ has_larger_distance_to_point(const PointH2<R>& p,
 
 template < class R>
 CGAL_KERNEL_INLINE
-Comparison_result
+typename R::Comparison_result
 compare_signed_distance_to_line(const LineH2<R>&  l,
                                 const PointH2<R>& p,
                                 const PointH2<R>& q)
@@ -111,7 +111,7 @@ compare_signed_distance_to_line(const LineH2<R>&  l,
 
 template < class R>
 CGAL_KERNEL_INLINE
-bool
+typename R::Boolean
 has_larger_signed_distance_to_line(const LineH2<R>&  l,
                                     const PointH2<R>& p,
                                     const PointH2<R>& q)
@@ -140,7 +140,7 @@ has_larger_signed_distance_to_line(const LineH2<R>&  l,
 
 template < class R>
 CGAL_KERNEL_INLINE
-bool
+typename R::Boolean
 has_smaller_signed_distance_to_line(const LineH2<R>&  l,
                                     const PointH2<R>& p,
                                     const PointH2<R>& q)
@@ -167,7 +167,7 @@ has_smaller_signed_distance_to_line(const LineH2<R>&  l,
 
 template < class R>
 CGAL_KERNEL_MEDIUM_INLINE
-Comparison_result
+typename R::Comparison_result
 compare_signed_distance_to_line(const PointH2<R>& p,
                                 const PointH2<R>& q,
                                 const PointH2<R>& r,
@@ -208,7 +208,7 @@ compare_signed_distance_to_line(const PointH2<R>& p,
 
 template < class R>
 CGAL_KERNEL_MEDIUM_INLINE
-bool
+typename R::Boolean
 has_smaller_signed_distance_to_line(const PointH2<R>& p,
                                     const PointH2<R>& q,
                                     const PointH2<R>& r,
@@ -241,7 +241,7 @@ has_smaller_signed_distance_to_line(const PointH2<R>& p,
 
 template < class R>
 CGAL_KERNEL_MEDIUM_INLINE
-bool
+typename R::Boolean
 has_larger_signed_distance_to_line(const PointH2<R>& p,
                                     const PointH2<R>& q,
                                     const PointH2<R>& r,
