@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_3.h $
-// $Id: Projection_traits_3.h 214e072 2022-09-22T12:02:53+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_3.h $
+// $Id: include/CGAL/Kernel_23/internal/Projection_traits_3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mariette Yvinec, Sebastien Loriot, Mael Rouxel-Labbé
@@ -20,6 +20,7 @@
 
 #include <CGAL/Kernel/global_functions_2.h>
 #include <CGAL/Kernel_23/internal/Has_boolean_tags.h>
+#include <CGAL/Triangulation_structural_filtering_traits.h>
 
 namespace CGAL {
 
@@ -90,9 +91,11 @@ template <class R,int dim>
 class Construct_bbox_projected_2 {
 public:
   typedef typename R::Point_3     Point;
-  typedef Bbox_2 result_type;
 
-  Bbox_2 operator()(const Point& p) const { typename R::Construct_bbox_3 bb;  return Projector<R, dim>::bbox(bb(p)); }
+  Bbox_2 operator()(const Point& p) const {
+    typename R::Construct_bbox_3 bb;
+    return Projector<R, dim>::bbox(bb(p));
+  }
 };
 
 template <class R,int dim>
@@ -176,39 +179,43 @@ public:
 template <class R,int dim>
 class Side_of_bounded_circle_projected_3
 {
+  typedef typename R::Bounded_side Bounded_side;
+  typedef typename R::Point_3      Point;
+
 public:
-  typedef typename R::Point_3     Point;
   typename R::FT x(const Point &p) const { return Projector<R,dim>::x(p); }
   typename R::FT y(const Point &p) const { return Projector<R,dim>::y(p); }
 
-
   typename R::Point_2 project(const Point& p) const
   {
     return typename R::Point_2(x(p),y(p));
   }
-  CGAL::Bounded_side operator() (const Point &p,
-                                  const Point &q,
-                                  const Point &r,
-                                  const Point &s) const
-    {
-      return CGAL::side_of_bounded_circle(project(p),project(q),project(r),project(s) );
-    }
 
-    CGAL::Bounded_side operator() (const Point &p,
-                                  const Point &q,
-                                  const Point &r) const
-    {
-      return CGAL::side_of_bounded_circle(project(p),project(q),project(r));
-    }
+  Bounded_side operator()(const Point &p,
+                          const Point &q,
+                          const Point &r,
+                          const Point &s) const
+  {
+    return CGAL::side_of_bounded_circle(project(p),project(q),project(r),project(s) );
+  }
+
+  Bounded_side operator()(const Point &p,
+                          const Point &q,
+                          const Point &r) const
+  {
+    return CGAL::side_of_bounded_circle(project(p),project(q),project(r));
+  }
 };
 
 template <class R,int dim>
 class Compare_distance_projected_3
 {
 public:
+  typedef typename R::Comparison_result Comparison_result;
   typedef typename R::Point_3   Point_3;
   typedef typename R::Point_2   Point_2;
   typedef typename R::FT        RT;
+
   typename R::FT x(const Point_3 &p) const { return Projector<R,dim>::x(p); }
   typename R::FT y(const Point_3 &p) const { return Projector<R,dim>::y(p); }
 
@@ -254,22 +261,23 @@ template <class R, int dim>
 class Compare_signed_distance_to_line_projected_3
 {
 public:
+  typedef typename R::Comparison_result Comparison_result;
   typedef typename R::Point_3   Point_3;
   typedef typename R::Point_2   Point_2;
   typedef typename R::FT        RT;
+
   typename R::FT x(const Point_3 &p) const { return Projector<R,dim>::x(p); }
   typename R::FT y(const Point_3 &p) const { return Projector<R,dim>::y(p); }
-  typedef typename R::Comparison_result result_type;
 
   Point_2 project(const Point_3& p) const
   {
     return Point_2(x(p),y(p));
   }
 
-  result_type operator()(const Point_3& p,
-                         const Point_3& q,
-                         const Point_3& r,
-                         const Point_3& s) const
+  Comparison_result operator()(const Point_3& p,
+                               const Point_3& q,
+                               const Point_3& r,
+                               const Point_3& s) const
   {
     return typename R::Compare_signed_distance_to_line_2()
       (  project(p), project(q), project(r), project(s) );
@@ -280,22 +288,23 @@ template <class R, int dim>
 class Less_signed_distance_to_line_projected_3
 {
 public:
+  typedef typename R::Boolean   Boolean;
   typedef typename R::Point_3   Point_3;
   typedef typename R::Point_2   Point_2;
   typedef typename R::FT        RT;
+
   typename R::FT x(const Point_3 &p) const { return Projector<R,dim>::x(p); }
   typename R::FT y(const Point_3 &p) const { return Projector<R,dim>::y(p); }
-  typedef typename R::Boolean result_type;
 
   Point_2 project(const Point_3& p) const
   {
     return Point_2(x(p),y(p));
   }
 
-  result_type operator()(const Point_3& p,
-                         const Point_3& q,
-                         const Point_3& r,
-                         const Point_3& s) const
+  Boolean operator()(const Point_3& p,
+                     const Point_3& q,
+                     const Point_3& r,
+                     const Point_3& s) const
   {
     return typename R::Less_signed_distance_to_line_2()
       (  project(p), project(q), project(r), project(s) );
@@ -313,6 +322,7 @@ public:
   typedef typename R::Segment_3 Segment_3;
   typedef typename R::Segment_2 Segment_2;
   typedef typename R::FT        RT;
+
   typename R::FT x(const Point_3 &p) const { return Projector<R,dim>::x(p); }
   typename R::FT y(const Point_3 &p) const { return Projector<R,dim>::y(p); }
 
@@ -428,10 +438,10 @@ public:
 
 
 
-  boost::optional< boost::variant<Point_3,Segment_3> >
+  std::optional< std::variant<Point_3,Segment_3> >
   operator()(const Segment_3& s1, const Segment_3& s2) const
   {
-    typedef  boost::variant<Point_3, Segment_3> variant_type;
+    typedef  std::variant<Point_3, Segment_3> variant_type;
 
     Point_2 s1_source = project(s1.source());
     Point_2 s1_target = project(s1.target());
@@ -447,10 +457,10 @@ public:
 
     auto o = intersection(s1_2,s2_2);
     if(! o){
-      return boost::none;
+      return std::nullopt;
     }
 
-    if(const Segment_2* si = boost::get<Segment_2>(&*o)){
+    if(const Segment_2* si = std::get_if<Segment_2>(&*o)){
       FT src[3],tgt[3];
       //the third coordinate is the midpoint between the points on s1 and s2
       FT z1 = s1.source()[dim] + ( alpha(si->source(), s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
@@ -468,11 +478,11 @@ public:
       src[Projector<R,dim>::y_index] = si->source().y();
       tgt[Projector<R,dim>::x_index] = si->target().x();
       tgt[Projector<R,dim>::y_index] = si->target().y();
-      return boost::make_optional(variant_type(Segment_3( Point_3(src[0],src[1],src[2]),Point_3(tgt[0],tgt[1],tgt[2]) ) ) );
+      return std::make_optional(variant_type(Segment_3( Point_3(src[0],src[1],src[2]),Point_3(tgt[0],tgt[1],tgt[2]) ) ) );
     }
 
 
-    const Point_2* pi = boost::get<Point_2>(&*o);
+    const Point_2* pi = std::get_if<Point_2>(&*o);
     FT coords[3];
     //compute the third coordinate of the projected intersection point onto 3D segments
     FT z1 = s1.source()[dim] + ( alpha(*pi, s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
@@ -484,7 +494,7 @@ public:
 
     Point_3 res(coords[0],coords[1],coords[2]);
     CGAL_assertion(x(res)==pi->x() && y(res)==pi->y());
-    return boost::make_optional(variant_type(res));
+    return std::make_optional(variant_type(res));
   }
 };
 
@@ -597,8 +607,6 @@ class Compute_squared_length_projected_3
   typedef typename R::Vector_3    Vector_3;
   typedef typename R::FT          FT;
 
-  typedef FT result_type;
-
   FT x(const Vector_3 &v) const { return Projector<R,dim>::x(v); }
   FT y(const Vector_3 &v) const { return Projector<R,dim>::y(v); }
 
@@ -633,6 +641,7 @@ template <class R, int dim>
 class Compare_power_distance_projected_3
 {
 public:
+  typedef typename R::Comparison_result         Comparison_result;
   typedef typename R::Point_2                   Point_2;
   typedef typename R::Weighted_point_2          Weighted_point_2;
   typedef typename R::Point_3                   Point_3;
@@ -814,6 +823,7 @@ template <class R, int dim>
 class Power_side_of_bounded_power_circle_projected_3
 {
 public:
+  typedef typename R::Bounded_side              Bounded_side;
   typedef typename R::Point_2                   Point_2;
   typedef typename R::Weighted_point_2          Weighted_point_2;
   typedef typename R::Point_3                   Point_3;
@@ -829,24 +839,24 @@ public:
     return Weighted_point_2(Point_2(x(p), y(p)), wp.weight());
   }
 
-  CGAL::Bounded_side operator()(const Weighted_point_3 &wp,
-                                const Weighted_point_3 &wq,
-                                const Weighted_point_3 &wr,
-                                const Weighted_point_3 &ws) const
+  Bounded_side operator()(const Weighted_point_3 &wp,
+                          const Weighted_point_3 &wq,
+                          const Weighted_point_3 &wr,
+                          const Weighted_point_3 &ws) const
   {
     return CGAL::power_side_of_bounded_power_circle(project(wp), project(wq),
                                                     project(wr), project(ws));
   }
 
-  CGAL::Bounded_side operator()(const Weighted_point_3 &wp,
-                                const Weighted_point_3 &wq,
-                                const Weighted_point_3 &wr) const
+  Bounded_side operator()(const Weighted_point_3 &wp,
+                          const Weighted_point_3 &wq,
+                          const Weighted_point_3 &wr) const
   {
     return CGAL::power_side_of_bounded_power_circle(project(wp), project(wq), project(wr));
   }
 
-  CGAL::Bounded_side operator()(const Weighted_point_3 &wp,
-                                const Weighted_point_3 &wq) const
+  Bounded_side operator()(const Weighted_point_3 &wp,
+                          const Weighted_point_3 &wq) const
   {
     return CGAL::power_side_of_bounded_power_circle(project(wp), project(wq));
   }
@@ -970,10 +980,13 @@ public:
   typedef typename Rp::Construct_triangle_3                   Construct_triangle_2;
   typedef typename Rp::Construct_line_3                       Construct_line_2;
 
+  typedef typename Rp::Compare_xyz_3                          Compare_xy_2;
 
   struct Less_xy_2 {
-    typedef typename R::Boolean result_type;
-    bool operator()(const Point_2& p, const Point_2& q) const
+    typedef typename R::Comparison_result Comparison_result;
+    typedef typename R::Boolean Boolean;
+
+    Boolean operator()(const Point_2& p, const Point_2& q) const
     {
       Compare_x_2 cx;
       Comparison_result crx = cx(p,q);
@@ -986,8 +999,8 @@ public:
 
 
   struct Less_yx_2 {
-    typedef typename R::Boolean result_type;
-    bool operator()(const Point_2& p, const Point_2& q) const
+    typedef typename R::Boolean Boolean;
+    Boolean operator()(const Point_2& p, const Point_2& q) const
     {
       Compare_y_2 cy;
       Comparison_result cry = cy(p,q);
@@ -999,8 +1012,8 @@ public:
   };
 
   struct Equal_2 {
-    typedef typename R::Boolean result_type;
-    bool operator()(const Point_2& p, const Point_2& q) const
+    typedef typename R::Boolean Boolean;
+    Boolean operator()(const Point_2& p, const Point_2& q) const
     {
 
       Equal_x_2 eqx;
@@ -1010,8 +1023,8 @@ public:
   };
 
   struct Left_turn_2 {
-    typedef typename R::Boolean result_type;
-    bool operator()(const Point_2& p, const Point_2& q, const Point_2& r) const
+    typedef typename R::Boolean Boolean;
+    Boolean operator()(const Point_2& p, const Point_2& q, const Point_2& r) const
     {
 
       Orientation_2 ori;
@@ -1020,7 +1033,7 @@ public:
   };
 
   struct Collinear_2 {
-    typedef typename R::Boolean result_type;
+    typedef typename R::Boolean Boolean;
     bool operator()(const Point_2& p, const Point_2& q, const Point_2& r) const
     {
       Orientation_2 ori;
@@ -1064,6 +1077,10 @@ public:
   less_x_2_object() const
     { return Less_x_2();}
 
+  Compare_xy_2
+  compare_xy_2_object() const
+    { return Compare_xy_2();}
+
   Less_xy_2
   less_xy_2_object() const
     { return Less_xy_2();}
@@ -1210,7 +1227,15 @@ public:
 };
 
 
-} } //namespace CGAL::internal
+
+} // namespace internal
+
+template <class R, int dim>
+struct Triangulation_structural_filtering_traits<::CGAL::internal::Projection_traits_3<R,dim> > {
+  typedef typename Triangulation_structural_filtering_traits<R>::Use_structural_filtering_tag  Use_structural_filtering_tag;
+};
+
+ } //namespace CGAL
 
 #endif // CGAL_INTERNAL_PROJECTION_TRAITS_3_H
 
