@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Nef_3/include/CGAL/Nef_3/SNC_external_structure.h $
-// $Id: include/CGAL/Nef_3/SNC_external_structure.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Nef_3/include/CGAL/Nef_3/SNC_external_structure.h $
+// $Id: include/CGAL/Nef_3/SNC_external_structure.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -474,7 +474,7 @@ public:
     CGAL_forall_iterators(it,M4) {
       //    progress++;
       it->second.sort(Halfedge_key_lt());
-      CGAL_NEF_TRACEN("search opposite  "<<it->first);
+      CGAL_NEF_TRACEN("search opposite (M4)  "<<it->first);
       typename Halfedge_list::iterator itl;
       CGAL_forall_iterators(itl,it->second) {
         Halfedge_handle e1 = itl->e;
@@ -483,7 +483,7 @@ public:
         Halfedge_handle e2 = itl->e;
         CGAL_NEF_TRACEN("    " << e1->source()->point()
                         << " -> " << e2->source()->point());
-        CGAL_NEF_TRACEN(e1->vector()<<" -> "<<-e2->vector());
+        CGAL_NEF_TRACEN("    " << e1->vector()<<" -> "<<-e2->vector());
         make_twins(e1,e2);
         CGAL_assertion(e1->mark()==e2->mark());
 
@@ -494,7 +494,7 @@ public:
     CGAL_forall_iterators(it,M3) {
       //    progress++;
       it->second.sort(Halfedge_key_lt());
-      CGAL_NEF_TRACEN("search opposite  "<<it->first);
+      CGAL_NEF_TRACEN("search opposite (M3)  "<<it->first);
       typename Halfedge_list::iterator itl;
       CGAL_forall_iterators(itl,it->second) {
         Halfedge_handle e1 = itl->e;
@@ -503,7 +503,7 @@ public:
         Halfedge_handle e2 = itl->e;
         CGAL_NEF_TRACEN("    " << e1->source()->point()
                         << " -> " << e2->source()->point());
-        CGAL_NEF_TRACEN(e1->vector()<<" -> "<<-e2->vector());
+        CGAL_NEF_TRACEN("    " << e1->vector()<<" -> "<<-e2->vector());
         make_twins(e1,e2);
         CGAL_assertion(e1->mark()==e2->mark());
 
@@ -514,7 +514,7 @@ public:
     CGAL_forall_iterators(it,M2) {
       //    progress++;
       it->second.sort(Halfedge_key_lt());
-      CGAL_NEF_TRACEN("search opposite  "<<it->first);
+      CGAL_NEF_TRACEN("search opposite (M2)  "<<it->first);
       typename Halfedge_list::iterator itl;
       CGAL_forall_iterators(itl,it->second) {
         Halfedge_handle e1 = itl->e;
@@ -523,7 +523,7 @@ public:
         Halfedge_handle e2 = itl->e;
         CGAL_NEF_TRACEN("    " << e1->source()->point()
                         << " -> " << e2->source()->point());
-        CGAL_NEF_TRACEN(e1->vector()<<" -> "<<-e2->vector());
+        CGAL_NEF_TRACEN("    " << e1->vector()<<" -> "<<-e2->vector());
         make_twins(e1,e2);
         CGAL_assertion(e1->mark()==e2->mark());
 
@@ -534,7 +534,7 @@ public:
     CGAL_forall_iterators(it,M) {
       //    progress++;
       it->second.sort(Halfedge_key_lt());
-      CGAL_NEF_TRACEN("search opposite  "<<it->first);
+      CGAL_NEF_TRACEN("search opposite (M)  "<<it->first);
       typename Halfedge_list::iterator itl;
       CGAL_forall_iterators(itl,it->second) {
         Halfedge_handle e1 = itl->e;
@@ -543,7 +543,7 @@ public:
         Halfedge_handle e2 = itl->e;
         CGAL_NEF_TRACEN("    " << e1->source()->point()
                         << " -> " << e2->source()->point());
-        CGAL_NEF_TRACEN(e1->vector()<<" -> "<< -e2->vector());
+        CGAL_NEF_TRACEN("    " << e1->vector()<<" -> "<< -e2->vector());
         CGAL_assertion(e1->source()->point() != e2->source()->point());
         CGAL_assertion(e1->mark()==e2->mark());
         make_twins(e1,e2);
@@ -586,10 +586,16 @@ public:
             break;
       } else
 #endif
+        CGAL_assertion_code(bool found = false;)
         CGAL_For_all(cet,cete)
           if ( cet->circle() == ce->circle().opposite() &&
                cet->source()->twin() == ce->source() )
+        {
+            CGAL_assertion_code(found = true;)
             break;
+        }
+
+        CGAL_assertion(found);
 
 #ifdef CGAL_USE_TRACE
       if( cet->circle() != ce->circle().opposite() )
