@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/NewKernel_d/include/CGAL/NewKernel_d/Wrapper/Ref_count_obj.h $
-// $Id: Ref_count_obj.h ac8b6d4 2022-06-10T07:59:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/NewKernel_d/include/CGAL/NewKernel_d/Wrapper/Ref_count_obj.h $
+// $Id: include/CGAL/NewKernel_d/Wrapper/Ref_count_obj.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -33,7 +33,7 @@ class Ref_count_obj
   typedef typename Get_functor<Kbase, Construct_ttag<Tag_> >::type CBase;
 
   typedef Ref_count_obj                        Self;
-  CGAL_static_assertion((std::is_same<Self, typename Get_type<R_, Tag_>::type>::value));
+  static_assert(std::is_same<Self, typename Get_type<R_, Tag_>::type>::value);
 
 public:
   typedef R_ R;
