@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Point_set_processing_3/include/CGAL/OpenGR/compute_registration_transformation.h $
-// $Id: compute_registration_transformation.h c253679 2020-04-18T16:27:58+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Point_set_processing_3/include/CGAL/OpenGR/compute_registration_transformation.h $
+// $Id: include/CGAL/OpenGR/compute_registration_transformation.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Sebastien Loriot, Necip Fazil Yildiran
@@ -19,11 +19,10 @@
 
 #include <CGAL/Aff_transformation_3.h>
 #include <CGAL/assertions.h>
-#include <CGAL/boost/graph/Named_function_parameters.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/Iterator_range.h>
 
-#include <boost/type_traits/is_same.hpp>
 #include <boost/range/iterator_range.hpp>
 
 #include <gr/algorithms/FunctorSuper4pcs.h>
@@ -31,6 +30,8 @@
 
 #include <Eigen/Dense>
 
+#include <type_traits>
+
 namespace CGAL {
 
 namespace OpenGR {
@@ -276,7 +277,7 @@ compute_registration_transformation(const PointRange1& range1,    const PointRan
      \cgalParamNEnd
 
      \cgalParamNBegin{normal_map}
-       \cgalParamDescription{a property map associating normals to the elements of the poing set `point_set_2`}
+       \cgalParamDescription{a property map associating normals to the elements of the point set `point_set_2`}
        \cgalParamType{a model of `ReadablePropertyMap` whose key type is the value type
                       of the iterator of `PointRange2` and whose value type is `geom_traits::Vector_3`}
        \cgalParamDefault{Normals are computed and stored internally.}
@@ -288,40 +289,43 @@ compute_registration_transformation(const PointRange1& range1,    const PointRan
    registration score.
 */
 template <class PointRange1, class PointRange2,
-          class NamedParameters1, class NamedParameters2>
+          class NamedParameters1 = parameters::Default_named_parameters,
+          class NamedParameters2 = parameters::Default_named_parameters>
 #ifdef DOXYGEN_RUNNING
 std::pair<geom_traits::Aff_transformation_3, double>
 #else
-std::pair<typename CGAL::Point_set_processing_3::GetK<PointRange1, NamedParameters1>
-  ::Kernel::Aff_transformation_3, double>
+std::pair<typename Point_set_processing_3_np_helper<PointRange1, NamedParameters1>
+  ::Geom_traits::Aff_transformation_3, double>
 #endif
 compute_registration_transformation (const PointRange1& point_set_1, const PointRange2& point_set_2,
-                                     const NamedParameters1& np1, const NamedParameters2& np2)
+                                     const NamedParameters1& np1 = parameters::default_values(),
+                                     const NamedParameters2& np2 = parameters::default_values())
 {
-  namespace PSP = CGAL::Point_set_processing_3;
   namespace GR = gr;
   using parameters::choose_parameter;
   using parameters::get_parameter;
 
   // property map types
-  typedef typename CGAL::GetPointMap<PointRange1, NamedParameters1>::type PointMap1;
-  typedef typename CGAL::GetPointMap<PointRange2, NamedParameters2>::type PointMap2;
-  CGAL_static_assertion_msg((boost::is_same< typename boost::property_traits<PointMap1>::value_type,
-                                             typename boost::property_traits<PointMap2>::value_type> ::value),
+  typedef Point_set_processing_3_np_helper<PointRange1, NamedParameters1> NP_helper1;
+  typedef Point_set_processing_3_np_helper<PointRange2, NamedParameters2> NP_helper2;
+  typedef typename NP_helper1::Const_point_map PointMap1;
+  typedef typename NP_helper2::Const_point_map PointMap2;
+  static_assert(std::is_same< typename boost::property_traits<PointMap1>::value_type,
+                                           typename boost::property_traits<PointMap2>::value_type> ::value,
                             "The point type of input ranges must be the same");
 
-  typedef typename PSP::GetNormalMap<PointRange1, NamedParameters1>::type NormalMap1;
-  typedef typename PSP::GetNormalMap<PointRange2, NamedParameters2>::type NormalMap2;
-  CGAL_static_assertion_msg((boost::is_same< typename boost::property_traits<NormalMap1>::value_type,
-                                             typename boost::property_traits<NormalMap2>::value_type> ::value),
+  typedef typename NP_helper1::Normal_map NormalMap1;
+  typedef typename NP_helper2::Normal_map NormalMap2;
+  static_assert(std::is_same< typename boost::property_traits<NormalMap1>::value_type,
+                                           typename boost::property_traits<NormalMap2>::value_type> ::value,
                             "The vector type of input ranges must be the same");
 
-  typedef typename PSP::GetK<PointRange1, NamedParameters1>::Kernel Kernel;
+  typedef typename NP_helper1::Geom_traits Kernel;
 
-  PointMap1 point_map1 = choose_parameter(get_parameter(np1, internal_np::point_map), PointMap1());
-  NormalMap1 normal_map1 = choose_parameter(get_parameter(np1, internal_np::normal_map), NormalMap1());
-  PointMap2 point_map2 = choose_parameter(get_parameter(np2, internal_np::point_map), PointMap2());
-  NormalMap2 normal_map2 = choose_parameter(get_parameter(np2, internal_np::normal_map), NormalMap2());
+  PointMap1 point_map1 = NP_helper1::get_const_point_map(point_set_1, np1);
+  NormalMap1 normal_map1 = NP_helper2::get_normal_map(point_set_1, np1);
+  PointMap2 point_map2 = NP_helper2::get_const_point_map(point_set_2, np2);
+  NormalMap2 normal_map2 = NP_helper2::get_normal_map(point_set_2, np2);
 
   Options<Kernel> options;
   options.sample_size = choose_parameter(get_parameter(np1, internal_np::number_of_samples), 200);
@@ -340,32 +344,9 @@ compute_registration_transformation (const PointRange1& point_set_1, const Point
 
 }
 
-// convenience overloads
-template <class PointRange1, class PointRange2,
-          class NamedParameters1>
-std::pair<typename CGAL::Point_set_processing_3::GetK<PointRange1, NamedParameters1>
-  ::Kernel::Aff_transformation_3, double>
-compute_registration_transformation(const PointRange1& point_set_1, PointRange2& point_set_2,
-      const NamedParameters1& np1)
-{
-  namespace params = CGAL::Point_set_processing_3::parameters;
-  return compute_registration_transformation(point_set_1, point_set_2, np1, params::all_default(point_set_1));
-}
-
-template <class PointRange1, class PointRange2>
-std::pair<typename CGAL::Point_set_processing_3::GetK<PointRange1,
-          Named_function_parameters<bool, internal_np::all_default_t> >
-  ::Kernel::Aff_transformation_3, double>
-compute_registration_transformation(const PointRange1& point_set_1, PointRange2& point_set_2)
-{
-  namespace params = CGAL::Point_set_processing_3::parameters;
-  return compute_registration_transformation(point_set_1, point_set_2,
-                                             params::all_default(point_set_1),
-                                             params::all_default(point_set_2));
-}
-
 } } // end of namespace CGAL::OpenGR
 
 #endif // CGAL_LINKED_WITH_OPENGR
 
 #endif // CGAL_OPENGR_COMPUTE_REGISTRATION_TRANSFORMATION_H
+
