@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Periodic_2_triangulation_2/include/CGAL/Periodic_2_triangulation_2/internal/Static_filters/Periodic_2_orientation_2.h $
-// $Id: Periodic_2_orientation_2.h 5945e48 2021-09-17T08:14:06+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Periodic_2_triangulation_2/include/CGAL/Periodic_2_triangulation_2/internal/Static_filters/Periodic_2_orientation_2.h $
+// $Id: include/CGAL/Periodic_2_triangulation_2/internal/Static_filters/Periodic_2_orientation_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Nico Kruithof <Nico@nghk.nl>
@@ -93,12 +93,12 @@ public:
   typedef typename Kernel::Iso_rectangle_2        Iso_rectangle_2;
   typedef typename Kernel::Periodic_2_offset_2    Offset_2;
 
+  typedef typename Kernel:: Orientation            Orientation;
+
 public:
   const Iso_rectangle_2 * const _dom;
 
 public:
-  typedef typename Base::result_type  result_type;
-
   Periodic_2_orientation_2(const Iso_rectangle_2 * const dom,
                            const Base& o2b)
     : Base(o2b), _dom(dom)
@@ -107,7 +107,7 @@ public:
   using Base::operator();
 
   /// Normal static orientation test, copied from Orientation_2
-  result_type operator()(const Point_2 &p, const Point_2 &q, const Point_2 &r) const
+  Orientation operator()(const Point_2 &p, const Point_2 &q, const Point_2 &r) const
   {
     CGAL_PROFILER("Periodic_2_orientation_2 calls");
 
@@ -162,7 +162,7 @@ public:
 
 
   /// Static orientation test with offsets
-  result_type operator()(const Point_2 &p, const Point_2 &q, const Point_2 &r,
+  Orientation operator()(const Point_2 &p, const Point_2 &q, const Point_2 &r,
                          const Offset_2 &o_p, const Offset_2 &o_q, const Offset_2 &o_r) const
   {
 
