@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_2_impl.h $
-// $Id: Straight_skeleton_builder_2_impl.h e5f18d6 2023-04-27T11:58:19+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_2_impl.h $
+// $Id: include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_2_impl.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -34,7 +34,7 @@
 namespace CGAL {
 
 template<class Gt, class Ss, class V>
-Straight_skeleton_builder_2<Gt,Ss,V>::Straight_skeleton_builder_2 ( boost::optional<FT> aMaxTime, Traits const& aTraits, Visitor const& aVisitor )
+Straight_skeleton_builder_2<Gt,Ss,V>::Straight_skeleton_builder_2 ( std::optional<FT> aMaxTime, Traits const& aTraits, Visitor const& aVisitor )
   :
   mTraits(aTraits)
  ,mVisitor(aVisitor)
@@ -344,7 +344,7 @@ void Straight_skeleton_builder_2<Gt,Ss,V>::CollectNewEvents( Vertex_handle aNode
   // or vertex events (or edge events of course).
   //
   // Each vertex wavefront (reflex or not) results in one and only one event from a set of possible events.
-  // It can result in a edge event against the vertex wavefronts emerging from the adjacent vertices (in the current polygon, not
+  // It can result in an edge event against the vertex wavefronts emerging from the adjacent vertices (in the current polygon, not
   // in the input polygon); or it can result in a split event (or vertex event) against any other wavefront in the rest of
   // current polygon.
 
@@ -1194,7 +1194,7 @@ void Straight_skeleton_builder_2<Gt,Ss,V>::HandleSplitEvent( EventPtr aEvent, Ve
     Halfedge_handle lOppBorder = lEvent.triedge().e2() ;
 
     Vertex_handle lNewNode_L, lNewNode_R ;
-    boost::tie(lNewNode_L,lNewNode_R) = ConstructSplitEventNodes(lEvent,lOppR);
+    std::tie(lNewNode_L,lNewNode_R) = ConstructSplitEventNodes(lEvent,lOppR);
 
     // Triedge lTriedge = aEvent->triedge();
 
@@ -1419,7 +1419,7 @@ void Straight_skeleton_builder_2<Gt,Ss,V>::HandlePseudoSplitEvent( EventPtr aEve
     CGAL_STSKEL_BUILDER_TRACE( 4, "LReed = " << v2str(*lRSeed) );
 
     Vertex_handle lNewNode_L, lNewNode_R ;
-    boost::tie(lNewNode_L,lNewNode_R) = ConstructPseudoSplitEventNodes(lEvent);
+    std::tie(lNewNode_L,lNewNode_R) = ConstructPseudoSplitEventNodes(lEvent);
 
     Halfedge_handle lNBisector_LO = SSkelEdgesPushBack( Halfedge(mEdgeID  ),Halfedge(mEdgeID+1) );
     Halfedge_handle lNBisector_RO = SSkelEdgesPushBack( Halfedge(mEdgeID+2),Halfedge(mEdgeID+3) );
@@ -1622,7 +1622,7 @@ template<class Gt, class Ss, class V>
 void Straight_skeleton_builder_2<Gt,Ss,V>::MergeSplitNodes ( Vertex_handle_pair aSplitNodes )
 {
   Vertex_handle lLNode, lRNode ;
-  boost::tie(lLNode,lRNode)=aSplitNodes;
+  std::tie(lLNode,lRNode)=aSplitNodes;
 
   Halfedge_handle lIBisectorL1 = lLNode->primary_bisector()->opposite();
   Halfedge_handle lIBisectorR1 = lRNode->primary_bisector()->opposite();
@@ -2037,7 +2037,7 @@ bool Straight_skeleton_builder_2<Gt,Ss,V>::MergeCoincidentNodes()
 
 // For weighted skeletons of polygons with holes, one can create non-simply-connected skeleton faces.
 // This is a problem both because it is not a valid HDS, and because we walk skeleton face borders
-// in polygon offseting. We add so-called artificial nodes and bisectors to ensure that faces
+// in polygon offsetting. We add so-called artificial nodes and bisectors to ensure that faces
 // are simply-connected by shooting rays from the topmost vertex of the bisectors of the skeleton
 // of the hole(s).
 template<class Gt, class Ss, class V>
@@ -2317,7 +2317,7 @@ extreme_h /     \                          extreme_h /     \
 
       // This is not a valid triedge because split_h is not a contour halfedge, but we need
       // to know which skeleton bisector the line orthogonal to contour_h interscets.
-      // The pair of identical contour halfedges at e0 and e1 is the marker for artifical vertices
+      // The pair of identical contour halfedges at e0 and e1 is the marker for artificial vertices
       SetVertexTriedge(new_v, artificial_event->triedge());
       SetTrisegment(new_v, artificial_event->trisegment());
 
