@@ -1,12 +1,12 @@
 #include <Rcpp.h>
 // Copyright (c) 2003-2007  INRIA Sophia-Antipolis (France).
-// Copyright (c) 2008,2011  GeometryFactory Sarl (France)
+// Copyright (c) 2008,2011,2024  GeometryFactory Sarl (France)
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Poisson_surface_reconstruction_3/include/CGAL/Surface_mesher/Poisson_implicit_surface_oracle_3.h $
-// $Id: Poisson_implicit_surface_oracle_3.h ce65fa9 2022-09-28T11:53:10+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Poisson_surface_reconstruction_3/include/CGAL/Surface_mesher/Poisson_implicit_surface_oracle_3.h $
+// $Id: include/CGAL/Surface_mesher/Poisson_implicit_surface_oracle_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,9 +18,8 @@
 #include <CGAL/license/Poisson_surface_reconstruction_3.h>
 
 
-#include <CGAL/Surface_mesher/Null_oracle_visitor.h>
 #include <CGAL/point_generators_3.h>
-#include <CGAL/Surface_mesher/Sphere_oracle_3.h>
+#include <CGAL/Poisson_surface_reconstruction_3/internal/Poisson_sphere_oracle_3.h>
 #include <CGAL/Surface_mesher/Implicit_surface_oracle_3.h>
 #include <CGAL/Real_embeddable_traits.h>
 #include <CGAL/squared_distance_3.h>
@@ -57,7 +56,7 @@ namespace CGAL {
       Return_min<typename Transform_functor_::result_type>,
     class Point_creator = Creator_uniform_3<typename GT::FT,
                                             typename GT::Point_3>,
-    class Visitor = Null_oracle_visitor
+    class Visitor = Poisson_null_oracle_visitor
     >
   class Poisson_implicit_surface_oracle_3
   {
@@ -69,7 +68,7 @@ namespace CGAL {
                                       Point_creator,
                                       Visitor> Self;
 
-    typedef Sphere_oracle_3<GT, Point_creator> Sphere_oracle;
+    typedef Poisson_sphere_oracle_3<GT, Point_creator> Sphere_oracle;
 
     typedef typename GT::Point_3 Point;
 
@@ -288,8 +287,8 @@ namespace CGAL {
         Cell_handle c1, c2;
         bool c1_is_inf, c2_is_inf;
 
-        boost::tie(value_at_p1, c1, c1_is_inf) = surface.function().special_func(p1);
-        boost::tie(value_at_p2, c2, c2_is_inf) = surface.function().special_func(p2);
+        std::tie(value_at_p1, c1, c1_is_inf) = surface.function().special_func(p1);
+        std::tie(value_at_p2, c2, c2_is_inf) = surface.function().special_func(p2);
 
         // If both extremities are in the same volume component, returns
         // no intersection.
@@ -322,7 +321,7 @@ namespace CGAL {
           Cell_handle c_at_mid;
           FT value_at_mid;
           bool c_is_inf;
-          boost::tie(value_at_mid, c_at_mid, c_is_inf) = surface.function().special_func(mid);
+          std::tie(value_at_mid, c_at_mid, c_is_inf) = surface.function().special_func(mid);
 
           if ( squared_distance(p1, p2) < squared_distance_bound )
           // If the two points are close, then we must decide
@@ -330,7 +329,7 @@ namespace CGAL {
 #ifdef CGAL_SURFACE_MESHER_DEBUG_CLIPPED_SEGMENT
             Rcpp::Rcerr << "=" << debug_point(surface, mid) << "\n";
 #endif
-            // the following function conditionnally call
+            // the following function conditionally call
             // mid.set_on_surface(...) if mid has such a function.
             set_on_surface(mid,
                            surface_identifiers_generator(transform_functor(value_at_p1),
